@@ -49,7 +49,7 @@ class FelderaClient:
         api_key: Optional[str] = None,
         timeout: Optional[float] = None,
         connection_timeout: Optional[float] = None,
-        requests_verify: bool | str = True,
+        requests_verify: Optional[bool | str] = None,
     ) -> None:
         """
         :param url: The url to Feldera API (ex: https://try.feldera.com). If
@@ -185,7 +185,7 @@ class FelderaClient:
                 elapsed = time.monotonic() - start_time
                 if elapsed > timeout_s:
                     raise TimeoutError(
-                        f"Timed out waiting for pipeline {pipeline_name} to"
+                        f"Timed out waiting for pipeline {pipeline_name} to "
                         f"transition to '{state}' state"
                     )
 
@@ -287,6 +287,21 @@ Reason: The pipeline is in a STOPPED state due to the following error:
             },
         )
 
+    def testing_force_update_platform_version(self, name: str, platform_version: str):
+        self.http.post(
+            path=f"/pipelines/{name}/testing",
+            params={"set_platform_version": platform_version},
+        )
+
+    def update_pipeline_runtime(self, name: str):
+        """
+        Recompile a pipeline with the Feldera runtime version included in the currently installed Feldera platform.
+
+        :param name: The name of the pipeline
+        """
+
+        self.http.post(path=f"/pipelines/{name}/update_runtime")
+
     def delete_pipeline(self, name: str):
         """
         Deletes a pipeline by name
